@@ -20,12 +20,12 @@ import logging
 import os
 import re
 import sys
+import urllib
 
 import netaddr
 import optparse
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-import urllib2
 
 from networking_bagpipe.bagpipe_bgp.api import config as api_config
 from networking_bagpipe.bagpipe_bgp.common import net_utils
@@ -262,7 +262,7 @@ def main():
                       default=None,
                       type="int",
                       help="BGP LOCAL PREF attribute (optional)")
-    (options, _) = parser.parse_args()
+    (options, _unused) = parser.parse_args()
 
     if not(options.operation):
         parser.error("Need to specify --attach or --detach")
@@ -310,7 +310,7 @@ def main():
             options.netns = options.vpn_instance_id
 
         try:
-            (_, options.if2netns) = options.port.split(":")
+            (_unused, options.if2netns) = options.port.split(":")
         except Exception:
             options.if2netns = get_vpn2ns_if_name(options.netns)
 
@@ -410,16 +410,17 @@ def main():
     print("request: %s" % json_data)
 
     os.environ['NO_PROXY'] = "127.0.0.1"
-    req = urllib2.Request("http://127.0.0.1:%d/%s_localport" %
-                          (cfg.CONF.API.port, options.operation), json_data,
-                          {'Content-Type': 'application/json'})
+    req = urllib.request.Request(
+        "http://127.0.0.1:%d/%s_localport" %
+        (cfg.CONF.API.port, options.operation),
+        json_data, {'Content-Type': 'application/json'})
     try:
-        response = urllib2.urlopen(req)
+        response = urllib.request.urlopen(req)
         response_content = response.read()
         response.close()
 
         print("response: %d %s" % (response.getcode(), response_content))
-    except urllib2.HTTPError as e:
+    except urllib.error.HTTPError as e:
         error_content = e.read()
         print("   %s" % error_content)
         sys.exit("error %d, reason: %s" % (e.code, e.reason))
