@@ -14,7 +14,7 @@
 #    under the License.
 
 import copy
-import mock
+from unittest import mock
 
 import netaddr
 
@@ -1180,8 +1180,8 @@ class TestBgpvpnAgentExtensionMixin(object):
             'export_rt': ['12345:1', '12345:2', '12345:3', '12345:8',
                           '12345:6']
         }
-        self.assertItemsEqual(result['import_rt'], expected['import_rt'])
-        self.assertItemsEqual(result['export_rt'], expected['export_rt'])
+        self.assertCountEqual(result['import_rt'], expected['import_rt'])
+        self.assertCountEqual(result['export_rt'], expected['export_rt'])
 
     def test_port_association_before_port_up(self):
         port_assoc = self._fake_port_assoc(
@@ -1947,7 +1947,7 @@ class TestOVSAgentExtension(base.BaseTestOVSAgentExtension,
         )
 
         self.int_br.add_flow.assert_called_once_with(
-            table=ovs_agt_constants.ACCEPTED_EGRESS_TRAFFIC_TABLE,
+            table=ovs_agt_constants.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE,
             priority=3,
             dl_src="00:00:5e:2a:10:00",
             actions="NORMAL",
@@ -2088,7 +2088,7 @@ class TestOVSAgentExtension(base.BaseTestOVSAgentExtension,
             )
 
             int_add_flow.assert_called_once_with(
-                table=ovs_agt_constants.ACCEPTED_EGRESS_TRAFFIC_TABLE,
+                table=ovs_agt_constants.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE,
                 priority=2,
                 reg6=vlan,
                 dl_dst=GW_MAC,
@@ -2126,7 +2126,7 @@ class TestOVSAgentExtension(base.BaseTestOVSAgentExtension,
                 any_order=True
             )
             int_delete_flows.assert_called_once_with(
-                table=ovs_agt_constants.ACCEPTED_EGRESS_TRAFFIC_TABLE,
+                table=ovs_agt_constants.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE,
                 reg6=vlan)
 
     def test_gateway_redirection_ovs_restart(self):
